aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio/Tango.Integration/ExternalBridge/IExternalBridgeService.cs
diff options
context:
space:
mode:
Diffstat (limited to 'Software/Visual_Studio/Tango.Integration/ExternalBridge/IExternalBridgeService.cs')
-rw-r--r--Software/Visual_Studio/Tango.Integration/ExternalBridge/IExternalBridgeService.cs48
1 files changed, 9 insertions, 39 deletions
diff --git a/Software/Visual_Studio/Tango.Integration/ExternalBridge/IExternalBridgeService.cs b/Software/Visual_Studio/Tango.Integration/ExternalBridge/IExternalBridgeService.cs
index c7d2c8d5c..c0b41fd00 100644
--- a/Software/Visual_Studio/Tango.Integration/ExternalBridge/IExternalBridgeService.cs
+++ b/Software/Visual_Studio/Tango.Integration/ExternalBridge/IExternalBridgeService.cs
@@ -1,7 +1,5 @@
-using Google.Protobuf;
-using System;
+using System;
using System.Collections.Generic;
-using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
@@ -9,27 +7,21 @@ using Tango.BL.Entities;
using Tango.Integration.Operation;
using Tango.PMR.Integration;
using Tango.Transport;
-using Tango.Transport.Adapters;
using Tango.Transport.Transporters;
namespace Tango.Integration.ExternalBridge
{
- public interface IExternalBridgeService
+ public interface IExternalBridgeService : ITransporter
{
/// <summary>
- /// Gets the collection of logged-in receivers.
- /// </summary>
- List<ExternalBridgeReceiver> ActiveReceivers { get; }
-
- /// <summary>
/// Occurs when a new client is waiting for authentication.
/// </summary>
event EventHandler<ExternalBridgeClientConnectedEventArgs> ConnectionRequest;
/// <summary>
- /// Occurs when the current full control session has disconnected.
+ /// Occurs when the last client has been disconnected.
/// </summary>
- event EventHandler FullControlSessionDisconnected;
+ event EventHandler ClientDisconnected;
/// <summary>
/// Occurs when the service has received a new color profile request.
@@ -47,21 +39,6 @@ namespace Tango.Integration.ExternalBridge
Machine Machine { get; set; }
/// <summary>
- /// Gets or sets the SignalR configuration.
- /// </summary>
- ExternalBridgeSignalRConfiguration SignalRConfiguration { get; set; }
-
- /// <summary>
- /// Gets the current full control session receiver.
- /// </summary>
- ExternalBridgeReceiver FullControlSessionReceiver { get; }
-
- /// <summary>
- /// Gets or sets the TCP transport adapter write mode when creating a TCP receiver.
- /// </summary>
- TcpTransportAdapterWriteMode TcpTransportAdapterWriteMode { get; set; }
-
- /// <summary>
/// Gets a value indicating whether this instance is started.
/// </summary>
bool IsStarted { get; }
@@ -72,9 +49,9 @@ namespace Tango.Integration.ExternalBridge
bool Enabled { get; set; }
/// <summary>
/// Gets a value indicating whether there are any connected sessions.
/// </summary>
- bool HasSessions { get; }
+ bool IsInSession { get; }
/// <summary>
/// Starts this instance.
@@ -89,18 +66,11 @@ namespace Tango.Integration.ExternalBridge
/// <summary>
/// Disconnects the current remote client session.
/// </summary>
- void DisconnectFullControlSession();
-
- /// <summary>
- /// Registers the request handler.
- /// </summary>
- /// <param name="handler">The handler.</param>
- void RegisterRequestHandler(IExternalBridgeRequestHandler handler);
+ void DisconnectSession();
/// <summary>
- /// Unregisters the request handler.
+ /// Gets the current session login intent.
/// </summary>
- /// <param name="handler">The handler.</param>
- void UnregisterRequestHandler(IExternalBridgeRequestHandler handler);
+ ExternalBridgeLoginIntent SessionIntent { get; }
}
}
@@ -72,9 +49,9 @@ namespace Tango.Integration.ExternalBridge
bool Enabled { get; set; }
/// <summary>
- /// Gets a value indicating whether there are any connected sessions.
+ /// Gets a value indicating whether a remote client is authenticated and in session.
/// </summary>